@@ -24,7 +24,6 @@ extern "C" {
 
 struct fsdmidata;
 struct attrlist_cursor;
-struct parent_cursor;
 struct parent;
 
 extern int  path_to_handle (char *__path, void **__hanp, size_t *__hlen);
@@ -41,14 +40,12 @@ extern int  attr_multi_by_handle (void *__hanp, size_t __hlen, void *__buf,
 extern int  attr_list_by_handle (void *__hanp, size_t __hlen, void *__buf,
 				 size_t __bufsize, int __flags,
 				 struct attrlist_cursor *__cursor);
-extern int  getparents_by_handle(void *__hanp, size_t __hlen,
-				 struct parent *__buf, size_t __bufsize,
-				 struct parent_cursor *__cursor,
-				 unsigned int *__count, unsigned int *__more);
-extern int  getparentpaths_by_handle(void *__hanp, size_t __hlen,
-				     struct parent *__buf, size_t __bufsize,
-				     struct parent_cursor *__cursor,
-				     unsigned int *__count, unsigned int *__more);
+extern int  parents_by_handle(void *__hanp, size_t __hlen,
+			      struct parent *__buf, size_t __bufsize,
+			      unsigned int *__count);
+extern int  parentpaths_by_handle(void *__hanp, size_t __hlen,
+				  struct parent *__buf, size_t __bufsize,
+				  unsigned int *__count);
 extern int  fssetdm_by_handle (void *__hanp, size_t __hlen,
 			       struct fsdmidata *__fsdmi);
 
